# Conditional Attributes
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/conditional-attributes#overview)
  * [Key Concepts](https://help.sap.com/docs/leanix/ea/conditional-attributes#key-concepts)
  * [Defining Conditional Attribute](https://help.sap.com/docs/leanix/ea/conditional-attributes#defining-conditional-attribute)
  * [Combining Conditions](https://help.sap.com/docs/leanix/ea/conditional-attributes#combining-conditions)


Conditional attributes allow fields and relations in fact sheets to be visible based on related field values. Conditional attributes enables tailoring of attributes for subtypes, streamlining subtype management.
